Learn R Programming

xegaGaGene (version 1.0.0.4)

newPipeline: Converts a gene into a genetic operator pipeline (a function closure).

Description

The pipeline is evaluate(gene).

Usage

newPipeline(g, lF)

Value

Closure of genetic operator pipeline without mutation and crossover. The argument of the closure lF

configures the behavior of the pipeline.

Arguments

g

A gene.

lF

The local function configuration.

Details

newPipeline is a constructor of a function closure which contains the evaluation of a gene.

See Also

Other Genetic Operator Pipelines: newCross2Mut1Pipeline(), newCross2Mut2Pipeline(), newCross2Pipeline(), newCrossMut2Pipeline(), newCrossMutPipeline(), newCrossPipeline(), newMutPipeline()

Examples

Run this code
lFxegaGaGene$CrossGene<-xegaGaCrossGene
lFxegaGaGene$MutationRate<-function(fit, lF) {0.5}
lFxegaGaGene$CrossRate<-function(fit, lF) {0.5}
lFxegaGaGene$Accept<-function(OperatorPipeline, gene, lF) {gene}
g<-xegaGaInitGene(lFxegaGaGene)
a<-newPipeline(g, lFxegaGaGene)
print(a)
a(lFxegaGaGene)

Run the code above in your browser using DataLab