Learn R Programming

xegaGaGene (version 1.0.0.6)

newPipelineG: Converts a gene into a gene with genetic operator pipeline.

Description

The pipeline is evaluate(gene).

Usage

newPipelineG(g)

Value

A gene with embedded genetic operator pipeline without mutation and crossover. The argument lF of the function $Pipeline

configures the behavior of the pipeline.

Arguments

g

A gene.

Details

newPipelineG is a constructor which integrates a genetic operator pipeline which contains the evaluation of a gene into a gene.

See Also

Other Genetic Operator Pipelines in Gene: newCross2Mut1PipelineG(), newCross2Mut2PipelineG(), newCross2PipelineG(), newCrossMut2PipelineG(), newCrossMutPipelineG(), newCrossPipelineG(), newMutPipelineG()

Examples

Run this code
g<-xegaGaInitGene(lFxegaGaGene)
a<-newPipelineG(g)
print(a)
b<-a$Pipeline(a, lFxegaGaGene)
print(b)

Run the code above in your browser using DataLab