Learn R Programming

xegaGaGene (version 1.0.0.6)

xegaGaGeneMap: Map the bit strings of a binary gene to parameters in an interval.

Description

xegaGaGeneMap() maps the bit strings of a binary string to parameters in an interval. Bit vectors are mapped into equispaced numbers in the interval. Examples: Optimization of problems with real-valued parameter vectors.

Usage

xegaGaGeneMap(gene, penv)

Value

The decoded gene (the phenotype).

Arguments

gene

A binary gene (the genotype).

penv

A problem environment.

See Also

Other Decoder: xegaGaDecodeGene(), xegaGaGeneMapGray(), xegaGaGeneMapIdentity(), xegaGaGeneMapPerm()

Examples

Run this code
gene<-xegaGaInitGene(lFxegaGaGene)
xegaGaGeneMap(gene$gene1, lFxegaGaGene$penv)

Run the code above in your browser using DataLab