xegaGaGeneMapGray: Map the bit strings of a gray-coded gene to parameters in an interval.
Description
xegaGaGeneMapGray() maps the bit strings of
a binary string
interpreted as Gray codes to parameters in an interval.
Bit vectors are mapped into equispaced numbers in the interval.
Examples: Optimization of problems with real-valued
parameter vectors.
Usage
xegaGaGeneMapGray(gene, penv)
Value
The decoded gene (the phenotype).
Arguments
gene
A binary gene (the genotype).
penv
A problem environment.
See Also
Other Decoder:
xegaGaDecodeGene(),
xegaGaGeneMap(),
xegaGaGeneMapIdentity(),
xegaGaGeneMapPerm()