Learn R Programming

xegaGaGene (version 1.0.0.4)

xegaGaGeneMapIdentity: Map the bit strings of a binary gene to an identical bit vector.

Description

xegaGaGeneMapIdentity() maps the bit strings of a binary vector to an identical binary vector. Faster for all problems with single-bit coding. Examples: Knapsack, Number Partitioning into 2 partitions.

Usage

xegaGaGeneMapIdentity(gene, penv)

Value

A binary gene (the phenotype).

Arguments

gene

A binary gene (the genotype).

penv

A problem environment.

See Also

Other Decoder: xegaGaDecodeGene(), xegaGaGeneMap(), xegaGaGeneMapGray(), xegaGaGeneMapPerm()

Examples

Run this code
gene<-xegaGaInitGene(lFxegaGaGene)
xegaGaGeneMapIdentity(gene$gene1, lFxegaGaGene$penv)

Run the code above in your browser using DataLab