Learn R Programming

xegaGaGene (version 1.0.0.6)

xegaGaGeneMapPerm: Map the bit strings of a binary gene to a permutation.

Description

xegaGaGeneMapPerm() maps the bit strings of a binary string to a permutation of integers. Example: Traveling Salesman Problem (TSP).

Usage

xegaGaGeneMapPerm(gene, penv)

Value

A permutation (the decoded gene (the phenotype))

Arguments

gene

A binary gene (the genotype).

penv

A problem environment.

See Also

Other Decoder: xegaGaDecodeGene(), xegaGaGeneMap(), xegaGaGeneMapGray(), xegaGaGeneMapIdentity()

Examples

Run this code
gene<-xegaGaInitGene(lFxegaGaGene)
xegaGaGeneMapPerm(gene$gene1, lFxegaGaGene$penv)

Run the code above in your browser using DataLab