powered by
The pipeline is evaluate(gene).
evaluate(gene)
newPipelineG(g)
A gene with embedded genetic operator pipeline without mutation and crossover. The argument lF of the function $Pipeline
lF
$Pipeline
configures the behavior of the pipeline.
A gene.
newPipelineG is a constructor which integrates a genetic operator pipeline which contains the evaluation of a gene into a gene.
newPipelineG
Other Genetic Operator Pipelines in Gene: newCross2Mut1PipelineG(), newCross2Mut2PipelineG(), newCross2PipelineG(), newCrossMut2PipelineG(), newCrossMutPipelineG(), newCrossPipelineG(), newMutPipelineG()
newCross2Mut1PipelineG()
newCross2Mut2PipelineG()
newCross2PipelineG()
newCrossMut2PipelineG()
newCrossMutPipelineG()
newCrossPipelineG()
newMutPipelineG()
g<-xegaGaInitGene(lFxegaGaGene) a<-newPipelineG(g) print(a) b<-a$Pipeline(a, lFxegaGaGene) print(b)
Run the code above in your browser using DataLab