xegaGaGeneMap: Map the bit strings of a binary gene to parameters in an interval.
Description
xegaGaGeneMap() maps the bit strings of a binary string
to parameters in an interval.
Bit vectors are mapped into equispaced numbers in the interval.
Examples: Optimization of problems with real-valued
parameter vectors.
Usage
xegaGaGeneMap(gene, penv)
Value
The decoded gene (the phenotype).
Arguments
gene
A binary gene (the genotype).
penv
A problem environment.
See Also
Other Decoder:
xegaGaDecodeGene(),
xegaGaGeneMapGray(),
xegaGaGeneMapIdentity(),
xegaGaGeneMapPerm()